@@ -14,7 +14,7 @@ except ImportError:
     from ordereddict import OrderedDict
 
 try:
-    from pip._internal import get_installed_distributions
+    from pip._internal.utils.misc import get_installed_distributions
     from pip._internal.operations.freeze import FrozenRequirement
 except ImportError:
     from pip import get_installed_distributions, FrozenRequirement
@@ -24,7 +24,7 @@ import pkg_resources
 # from graphviz import backend, Digraph
 
 
-__version__ = '0.13.0'
+__version__ = '0.13.2'
 
 
 flatten = chain.from_iterable
@@ -129,6 +129,13 @@ def guess_version(pkg_key, default='?'):
         return getattr(m, '__version__', default)
 
 
+def frozen_req_from_dist(dist):
+    try:
+        return FrozenRequirement.from_dist(dist)
+    except TypeError:
+        return FrozenRequirement.from_dist(dist, [])
+
+
 class Package(object):
     """Abstract class for wrappers around objects that pip returns.
 
@@ -156,7 +163,7 @@ class Package(object):
 
     @staticmethod
     def frozen_repr(obj):
-        fr = FrozenRequirement.from_dist(obj, [])
+        fr = frozen_req_from_dist(obj)
         return str(fr).strip()
 
     def __getattr__(self, key):
@@ -565,7 +572,7 @@ def _get_args():
 def main():
     args = _get_args()
     pkgs = get_installed_distributions(local_only=args.local_only,
-                                           user_only=args.user_only)
+                                       user_only=args.user_only)
 
     dist_index = build_dist_index(pkgs)
     tree = construct_tree(dist_index)
